import * as i0 from '@angular/core';
import { numberAttribute, Directive, Input, InjectionToken, inject, PLATFORM_ID, input, HostListener, ElementRef, booleanAttribute, DestroyRef, ViewContainerRef, TemplateRef, ChangeDetectorRef, HostBinding, NgModule, Injectable, Component, ChangeDetectionStrategy, Pipe, LOCALE_ID, DEFAULT_CURRENCY_CODE, Inject, makeEnvironmentProviders } from '@angular/core';
import { isPlatformBrowser, Location, CurrencyPipe } from '@angular/common';
import { Router } from '@angular/router';
import { s_from, getLogMessage, loggerOf, s_cut, s_isEmail, s_isUrl, s_lowerCaseAllExceptFirstLetter, s_truncate, s_upperCaseFirstLetter, s_stripWhitespace, s_imploder, a_pluck, d_timeLeft, d_timespan } from 'dfts-helper';
import { of, combineLatest, tap, catchError, throwError, switchMap, timer, map, distinctUntilChanged, startWith, shareReplay, mergeMap } from 'rxjs';
import { takeUntilDestroyed, toObservable, toSignal } from '@angular/core/rxjs-interop';
import { HttpContextToken, HttpResponse, HttpErrorResponse, HttpContext, HttpClient } from '@angular/common/http';
import { ViewportRuler } from '@angular/cdk/overlay';

class DfxAutofocus {
    constructor(elRef) {
        this.elRef = elRef;
        this.delay = 100;
    }
    ngAfterViewInit() {
        // Just an optional extra null check
        this.elRef.nativeElement?.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxAutofocus, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "17.3.0", type: DfxAutofocus, isStandalone: true, selector: "[focus]", inputs: { delay: ["focus", "delay", numberAttribute] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxAutofocus, decorators: [{
            type: Directive,
            args: [{
                    selector: '[focus]',
                    standalone: true,
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { delay: [{
                type: Input,
                args: [{ transform: numberAttribute, alias: 'focus' }]
            }] } });

const WINDOW = new InjectionToken('window');
const windowProvider = {
    provide: WINDOW,
    useFactory: () => {
        return isPlatformBrowser(inject(PLATFORM_ID)) ? window : undefined;
    },
};
const provideWindow = () => windowProvider;
function injectWindow() {
    return inject(WINDOW);
}

class DfxBackDirective {
    constructor() {
        this.location = inject(Location);
        this.router = inject(Router);
        this.window = injectWindow();
        this.fallbackUrl = input('/');
    }
    goBack() {
        if (this.window) {
            if (this.window.history.length > 1) {
                this.location.back();
            }
            else {
                this.window?.close();
            }
        }
        else {
            void this.router.navigateByUrl(this.fallbackUrl());
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxBackDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "17.3.0", type: DfxBackDirective, isStandalone: true, selector: "[back]", inputs: { fallbackUrl: { classPropertyName: "fallbackUrl", publicName: "fallbackUrl", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "click": "goBack()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxBackDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[back]',
                    standalone: true,
                }]
        }], propDecorators: { goBack: [{
                type: HostListener,
                args: ['click']
            }] } });

class DfxCountUp {
    constructor() {
        this.el = inject((ElementRef));
        this.window = injectWindow();
        this.count = 0;
        /**
         * How long you want the animation to take.
         * @param time time in ms; defaults to <code>4000</code>
         */
        this.animationDuration = 4000;
        this.clickable = true;
        this.counterRunning = false;
        // Calculate how long each ‘frame’ should last if we want to update the animation 60 times per second 1000/60
        this.frameDuration = 16.6;
        // An ease-out function that slows the count as it progresses
        this.easeOutQuad = (t) => t * (2 - t);
        // The animation function, which takes an Element
        this.animateCountUp = () => {
            // exit early if the counter is already running
            if (this.counterRunning || !this.window) {
                return;
            }
            if (this.count === 0) {
                this.el.nativeElement.innerText = '0';
                return;
            }
            this.counterRunning = true;
            // Use that to calculate how many frames we need to complete the animation
            const totalFrames = Math.round(this.animationDuration / this.frameDuration);
            let frame = 0;
            const countTo = this.count;
            // Start the animation running 60 times per second
            const animate = () => {
                frame++;
                // Calculate our progress as a value between 0 and 1
                // Pass that value to our easing function to get our
                // progress on a curve
                const progress = this.easeOutQuad(frame / totalFrames);
                // Use the progress value to calculate the current count
                const currentCount = Math.round(countTo * progress);
                // If the current count has changed, update the element
                if (parseInt(this.el.nativeElement.innerText, 10) !== currentCount) {
                    this.el.nativeElement.innerText = s_from(currentCount);
                }
                // If we’ve reached our last frame, stop the animation
                if (frame === totalFrames) {
                    this.counterRunning = false;
                }
                else {
                    // otherwise, continue the animation by calling animate again
                    this.window?.requestIdleCallback(animate);
                }
            };
            this.window.requestIdleCallback(animate);
        };
    }
    set countUp(it) {
        if (it) {
            this.count = it;
            this.animateCountUp();
        }
    }
    onMouseDown() {
        if (this.clickable) {
            this.animateCountUp();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCountUp, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "17.3.0", type: DfxCountUp, isStandalone: true, selector: "[countUp]", inputs: { countUp: ["countUp", "countUp", numberAttribute], animationDuration: ["animationDuration", "animationDuration", numberAttribute], clickable: ["clickable", "clickable", booleanAttribute] }, host: { listeners: { "mousedown": "onMouseDown()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCountUp, decorators: [{
            type: Directive,
            args: [{
                    selector: '[countUp]',
                    standalone: true,
                }]
        }], propDecorators: { countUp: [{
                type: Input,
                args: [{ transform: numberAttribute, required: true }]
            }], animationDuration: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], clickable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], onMouseDown: [{
                type: HostListener,
                args: ['mousedown']
            }] } });

class NgSubsContext {
}
/**
 * @deprecated Please use Signals
 */
class NgSubs {
    #destroyRef = inject(DestroyRef);
    #viewContainer = inject(ViewContainerRef);
    #templateRef = inject(TemplateRef);
    #changeDetector = inject(ChangeDetectorRef);
    #subscribable$ = [of({})];
    #context = new NgSubsContext();
    #subscription;
    set ngSub(inputSubscribable) {
        if (this.#subscription) {
            this.#subscription.unsubscribe();
        }
        this.#subscribable$ = inputSubscribable;
        this.#subscription = combineLatest(this.#subscribable$)
            .pipe(takeUntilDestroyed(this.#destroyRef))
            .subscribe((values) => {
            this.#context.$implicit = values;
            this.#context.ngSub = values;
            this.#changeDetector.markForCheck();
        });
    }
    ngOnInit() {
        this.#viewContainer.createEmbeddedView(this.#templateRef, this.#context);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: NgSubs, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.0", type: NgSubs, isStandalone: true, selector: "[ngSubs]", inputs: { ngSub: "ngSub" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: NgSubs, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngSubs]',
                    standalone: true,
                }]
        }], propDecorators: { ngSub: [{
                type: Input
            }] } });
class NgSubContext {
}
/**
 * @deprecated Please use Signals
 */
class NgSub {
    #viewContainer = inject(ViewContainerRef);
    #templateRef = inject(TemplateRef);
    #changeDetector = inject(ChangeDetectorRef);
    #destroyRef = inject(DestroyRef);
    #subscribable$ = of({});
    #context = new NgSubContext();
    #subscription;
    set ngSub(inputSubscribable) {
        if (this.#subscription) {
            this.#subscription.unsubscribe();
        }
        this.#subscribable$ = inputSubscribable;
        this.#subscription = this.#subscribable$.pipe(takeUntilDestroyed(this.#destroyRef)).subscribe((value) => {
            this.#context.$implicit = value;
            this.#context.ngSub = value;
            this.#changeDetector.markForCheck();
        });
    }
    ngOnInit() {
        this.#viewContainer.createEmbeddedView(this.#templateRef, this.#context);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: NgSub, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.0", type: NgSub, isStandalone: true, selector: "[ngSub]", inputs: { ngSub: "ngSub" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: NgSub, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngSub]',
                    standalone: true,
                }]
        }], propDecorators: { ngSub: [{
                type: Input
            }] } });

class DfxHideIfOnline {
    constructor() {
        this._isOffline = false;
    }
    get hidden() {
        return !this._isOffline;
    }
    setNetworkOffline() {
        this._isOffline = true;
    }
    setNetworkOnline() {
        this._isOffline = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnline, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.0", type: DfxHideIfOnline, isStandalone: true, selector: "[hideIfOnline]", host: { listeners: { "window:offline": "setNetworkOffline()", "window:online": "setNetworkOnline()" }, properties: { "hidden": "this.hidden" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnline, decorators: [{
            type: Directive,
            args: [{
                    selector: '[hideIfOnline]',
                    standalone: true,
                }]
        }], propDecorators: { hidden: [{
                type: HostBinding,
                args: ['hidden']
            }], setNetworkOffline: [{
                type: HostListener,
                args: ['window:offline']
            }], setNetworkOnline: [{
                type: HostListener,
                args: ['window:online']
            }] } });
class DfxHideIfOffline extends DfxHideIfOnline {
    get hidden() {
        return !super.hidden;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOffline, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.0", type: DfxHideIfOffline, isStandalone: true, selector: "[hideIfOffline]", host: { properties: { "hidden": "this.hidden" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOffline, decorators: [{
            type: Directive,
            args: [{
                    selector: '[hideIfOffline]',
                    standalone: true,
                }]
        }], propDecorators: { hidden: [{
                type: HostBinding,
                args: ['hidden']
            }] } });
class DfxHideIfOnlineOfflineModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnlineOfflineModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnlineOfflineModule, imports: [DfxHideIfOnline, DfxHideIfOffline], exports: [DfxHideIfOnline, DfxHideIfOffline] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnlineOfflineModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfOnlineOfflineModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DfxHideIfOnline, DfxHideIfOffline],
                    exports: [DfxHideIfOnline, DfxHideIfOffline],
                }]
        }] });

const BASE_URL_INTERCEPTOR = new HttpContextToken(() => false);
const LOGGING_INTERCEPTOR = new HttpContextToken(() => false);
const POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR = new HttpContextToken(() => false);

const HELPER_MOBILE_BREAKPOINT = new InjectionToken('HELPER_MOBILE_BREAKPOINT', {
    factory: () => 992,
});
const HELPER_BASE_URL = new InjectionToken('HELPER_BASE_URL', {
    factory: () => '',
});
const HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS = new InjectionToken('HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS', {
    factory: () => [],
});
const HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS = new InjectionToken('HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS', {
    factory: () => [],
});
const HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS = new InjectionToken('HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS', {
    factory: () => [],
});

function shouldIntercept(req, BY_PASS, ignorePaths) {
    if (BY_PASS && req.context.get(BY_PASS)) {
        return false;
    }
    if (!ignorePaths) {
        return true;
    }
    // Fastest method
    for (const path of ignorePaths) {
        if (req.url.includes(path)) {
            return false;
        }
    }
    return true;
}
function baseUrlInterceptor(req, next) {
    const baseUrl = inject(HELPER_BASE_URL);
    if (baseUrl.length > 0 && shouldIntercept(req, BASE_URL_INTERCEPTOR, inject(HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS))) {
        return next(req.clone({ url: `${baseUrl + req.url}` }));
    }
    if (baseUrl.length < 1) {
        console.log(getLogMessage('ERROR', 'httpClient', 'baseUrlInterceptor', 'baseUrl undefined! It looks like you are using baseUrlInterceptor() but forgot assigning a base url.'));
    }
    return next(req);
}
function loggingInterceptor(req, next) {
    if (!shouldIntercept(req, LOGGING_INTERCEPTOR, inject(HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS))) {
        return next(req);
    }
    let text = `URL: "${req.url}" ${req.params.keys().length > 0 ? ` | params: "${req.params.toString()}"` : ''}`;
    const startTime = Date.now();
    return next(req).pipe(tap({
        next: (event) => {
            if (event instanceof HttpResponse) {
                const elapsedTime = Date.now() - startTime;
                text = `Status: Success | ${text} | Elapsed time: ${elapsedTime}ms`;
                console.group(getLogMessage('LOG', 'httpClient', req.method, text));
                if (req.body !== undefined && req.body != null) {
                    console.log(getLogMessage('LOG', 'httpClient', req.method, 'Request body'), req.body);
                }
                if (event) {
                    console.log(getLogMessage('LOG', 'httpClient', req.method, 'Request response'), event);
                }
                console.groupEnd();
            }
        },
    }), catchError((error) => {
        if (error instanceof ErrorEvent) {
            text += ` | Error: ${error.message}`;
        }
        else if (error instanceof HttpErrorResponse) {
            text += ` | Error Status: ${error.status} | ${error.message}`;
        }
        const elapsedTime = Date.now() - startTime;
        text = `Status: Error   | ${text} | Elapsed time: ${elapsedTime}ms`;
        console.log(getLogMessage('ERROR', 'httpClient', req.method, text), error);
        return throwError(() => error);
    }));
}
function postPutJsonContentTypeInterceptor(req, next) {
    if (!shouldIntercept(req, POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR, inject(HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS))) {
        return next(req);
    }
    const method = req.method.toLowerCase();
    if (method.includes('post') || method.includes('put')) {
        return next(req.clone({ headers: req.headers.set('Content-Type', 'application/json') }));
    }
    return next(req);
}

class AbstractIgnorableInterceptor {
    constructor(BY_PASS, ignorePaths) {
        this.BY_PASS = BY_PASS;
        this.ignorePaths = ignorePaths;
        this.shouldIntercept = (req) => shouldIntercept(req, this.BY_PASS, this.ignorePaths);
    }
}

class BaseUrlInterceptor extends AbstractIgnorableInterceptor {
    constructor() {
        super(BASE_URL_INTERCEPTOR, inject(HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS));
        this.lumber = loggerOf('httpClient');
        this.baseUrl = inject(HELPER_BASE_URL);
    }
    intercept(req, next) {
        if (this.baseUrl.length > 0 && this.shouldIntercept(req)) {
            return next.handle(req.clone({ url: `${this.baseUrl + req.url}` }));
        }
        if (this.baseUrl.length < 1) {
            this.lumber.warning('intercept', 'baseUrl undefined! It looks like you are using the BaseUrlInterceptor but forgot assigning a base url.');
        }
        return next.handle(req);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: BaseUrlInterceptor, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: BaseUrlInterceptor }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: BaseUrlInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

const interceptorByPass = (context) => {
    return new ByPassInterceptorBuilder().context(context);
};
class ByPassInterceptorBuilder {
    constructor() {
        this.tokens = [];
    }
    static byPassInterceptor(context) {
        return interceptorByPass(context);
    }
    baseUrl() {
        this.tokens.push(BASE_URL_INTERCEPTOR);
        return this;
    }
    logging() {
        this.tokens.push(LOGGING_INTERCEPTOR);
        return this;
    }
    postPutJsonContentType() {
        this.tokens.push(POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR);
        return this;
    }
    custom(token) {
        this.tokens.push(token);
        return this;
    }
    context(context) {
        this._context = context;
        return this;
    }
    build() {
        this._context = this._context ?? new HttpContext();
        for (const token of this.tokens) {
            this._context.set(token, true);
        }
        return this._context;
    }
    buildAsOptions() {
        return { context: this.build() };
    }
}

class LoggingInterceptor extends AbstractIgnorableInterceptor {
    constructor() {
        super(LOGGING_INTERCEPTOR, inject(HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS));
        this.lumber = loggerOf('httpClient');
    }
    intercept(req, next) {
        if (!this.shouldIntercept(req)) {
            return next.handle(req);
        }
        let text = `URL: "${req.url}" ${req.params.keys().length > 0 ? ` | params: "${req.params.toString()}"` : ''}`;
        const startTime = Date.now();
        return next.handle(req).pipe(tap({
            next: (event) => {
                if (event instanceof HttpResponse) {
                    const elapsedTime = Date.now() - startTime;
                    text = `Status: Success | ${text} | Elapsed time: ${elapsedTime}ms`;
                    this.lumber.group(req.method, text);
                    if (req.body !== undefined && req.body !== null) {
                        this.lumber.log(req.method, 'Request body', req.body);
                    }
                    if (event) {
                        this.lumber.log(req.method, 'Request response', event);
                    }
                    this.lumber.groupEnd();
                }
            },
        }), catchError((error) => {
            if (error instanceof ErrorEvent) {
                text += ` | Error: ${error.message}`;
            }
            else if (error instanceof HttpErrorResponse) {
                text += ` | Error Status: ${error.status} | ${error.message}`;
            }
            const elapsedTime = Date.now() - startTime;
            text = `Status: Error   | ${text} | Elapsed time: ${elapsedTime}ms`;
            this.lumber.error(req.method, text, error);
            return throwError(() => error);
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoggingInterceptor, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoggingInterceptor }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: LoggingInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

class PostPutJsonContentTypeInterceptor extends AbstractIgnorableInterceptor {
    constructor() {
        super(POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR, inject(HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS));
    }
    intercept(req, next) {
        if (!this.shouldIntercept(req)) {
            return next.handle(req);
        }
        const method = req.method.toLowerCase();
        if (method.includes('post') || method.includes('put')) {
            return next.handle(req.clone({ headers: req.headers.set('Content-Type', 'application/json') }));
        }
        return next.handle(req);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: PostPutJsonContentTypeInterceptor, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: PostPutJsonContentTypeInterceptor }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: PostPutJsonContentTypeInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });

class DfxHideIfPingSucceeds {
    #httpClient;
    #changeDetectorRef;
    #url$;
    #refreshTime$;
    get hidden() {
        return !this.isOffline;
    }
    constructor() {
        this.#httpClient = inject(HttpClient);
        this.#changeDetectorRef = inject(ChangeDetectorRef);
        this.url = input.required();
        this.#url$ = toObservable(this.url);
        /**
         * Refresh time in seconds
         */
        this.refreshTime = input(10, { transform: numberAttribute });
        this.#refreshTime$ = toObservable(this.refreshTime);
        this.byPassLoggingInterceptor = interceptorByPass().logging().buildAsOptions();
        this.isOffline = false;
        combineLatest([this.#refreshTime$, this.#url$])
            .pipe(takeUntilDestroyed(), switchMap(([refreshTime, url]) => combineLatest([of(url), timer(0, refreshTime * 1000)])), switchMap(([url]) => this.#httpClient.get(url, this.byPassLoggingInterceptor).pipe(map(() => false), catchError(() => of(true)))), distinctUntilChanged())
            .subscribe((isOffline) => {
            this.isOffline = isOffline;
            this.#changeDetectorRef.markForCheck();
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingSucceeds, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "17.3.0", type: DfxHideIfPingSucceeds, isStandalone: true, selector: "[hideIfPingSucceeds]", inputs: { url: { classPropertyName: "url", publicName: "url", isSignal: true, isRequired: true, transformFunction: null }, refreshTime: { classPropertyName: "refreshTime", publicName: "refreshTime", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "hidden": "this.hidden" } }, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingSucceeds, decorators: [{
            type: Component,
            args: [{
                    selector: '[hideIfPingSucceeds]',
                    standalone: true,
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }], ctorParameters: () => [], propDecorators: { hidden: [{
                type: HostBinding,
                args: ['hidden']
            }] } });
class DfxHideIfPingFails extends DfxHideIfPingSucceeds {
    get hidden() {
        return !super.hidden;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingFails, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.0", type: DfxHideIfPingFails, isStandalone: true, selector: "[hideIfPingFails]", host: { properties: { "hidden": "this.hidden" } }, usesInheritance: true, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingFails, decorators: [{
            type: Component,
            args: [{
                    selector: '[hideIfPingFails]',
                    standalone: true,
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                }]
        }], propDecorators: { hidden: [{
                type: HostBinding,
                args: ['hidden']
            }] } });
class DfxHideIfPingModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingModule, imports: [DfxHideIfPingSucceeds, DfxHideIfPingFails], exports: [DfxHideIfPingSucceeds, DfxHideIfPingFails] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHideIfPingModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DfxHideIfPingSucceeds, DfxHideIfPingFails],
                    exports: [DfxHideIfPingSucceeds, DfxHideIfPingFails],
                }]
        }] });

class StopPropagationDirective {
    constructor() {
        this.stopPropagation = input(true, { transform: booleanAttribute });
    }
    onClick(event) {
        if (this.stopPropagation()) {
            event.stopPropagation();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: StopPropagationDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "17.3.0", type: StopPropagationDirective, isStandalone: true, selector: "[stopPropagation]", inputs: { stopPropagation: { classPropertyName: "stopPropagation", publicName: "stopPropagation", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "click": "onClick($event)" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: StopPropagationDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[stopPropagation]',
                    standalone: true,
                }]
        }], propDecorators: { onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class DfxCutPipe {
    transform(text, maxLength = 10, suffix = '...') {
        return s_cut(text, maxLength, suffix);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCutPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxCutPipe, isStandalone: true, name: "s_cut" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCutPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_cut',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxIsEmailPipe {
    transform(text) {
        return s_isEmail(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxIsEmailPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxIsEmailPipe, isStandalone: true, name: "s_isEmail" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxIsEmailPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_isEmail',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxIsUrlPipe {
    transform(text) {
        return s_isUrl(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxIsUrlPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxIsUrlPipe, isStandalone: true, name: "s_isUrl" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxIsUrlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_isUrl',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxLowerCaseExceptFirstLettersPipe {
    transform(text) {
        return s_lowerCaseAllExceptFirstLetter(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxLowerCaseExceptFirstLettersPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxLowerCaseExceptFirstLettersPipe, isStandalone: true, name: "s_lowerCaseAllExceptFirstLetter" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxLowerCaseExceptFirstLettersPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_lowerCaseAllExceptFirstLetter',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxTruncatePipe {
    transform(text, maxWords = 10, suffix = '...') {
        return s_truncate(text, maxWords, suffix);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTruncatePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxTruncatePipe, isStandalone: true, name: "s_truncate" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTruncatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_truncate',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxUpperCaseFirstLetterPipe {
    transform(text) {
        return s_upperCaseFirstLetter(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxUpperCaseFirstLetterPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxUpperCaseFirstLetterPipe, isStandalone: true, name: "s_upperCaseFirstLetter" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxUpperCaseFirstLetterPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_upperCaseFirstLetter',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxStripWhitespacePipe {
    transform(text) {
        return s_stripWhitespace(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxStripWhitespacePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxStripWhitespacePipe, isStandalone: true, name: "s_stripWhitespace" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxStripWhitespacePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_stripWhitespace',
                    standalone: true,
                    pure: true,
                }]
        }] });

const PIPES$1 = [
    DfxCutPipe,
    DfxIsEmailPipe,
    DfxIsUrlPipe,
    DfxLowerCaseExceptFirstLettersPipe,
    DfxStripWhitespacePipe,
    DfxTruncatePipe,
    DfxUpperCaseFirstLetterPipe,
];
class DfxStringModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxStringModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxStringModule, imports: [DfxCutPipe,
            DfxIsEmailPipe,
            DfxIsUrlPipe,
            DfxLowerCaseExceptFirstLettersPipe,
            DfxStripWhitespacePipe,
            DfxTruncatePipe,
            DfxUpperCaseFirstLetterPipe], exports: [DfxCutPipe,
            DfxIsEmailPipe,
            DfxIsUrlPipe,
            DfxLowerCaseExceptFirstLettersPipe,
            DfxStripWhitespacePipe,
            DfxTruncatePipe,
            DfxUpperCaseFirstLetterPipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxStringModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxStringModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: PIPES$1,
                    exports: PIPES$1,
                }]
        }] });

class DfxCurrencyCentPipe extends CurrencyPipe {
    constructor(_locale, __defaultCurrencyCode = 'USD') {
        super(_locale, __defaultCurrencyCode);
        this.__defaultCurrencyCode = __defaultCurrencyCode;
    }
    /**
     *
     * @param value The number to be formatted as currency.
     * @param currencyCode The [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) currency code,
     * such as `USD` for the US dollar and `EUR` for the euro. The default currency code can be
     * configured using the `DEFAULT_CURRENCY_CODE` injection token.
     * @param display The format for the currency indicator. One of the following:
     *   - `code`: Show the code (such as `USD`).
     *   - `symbol`(default): Show the symbol (such as `$`).
     *   - `symbol-narrow`: Use the narrow symbol for locales that have two symbols for their
     * currency.
     * For example, the Canadian dollar CAD has the symbol `CA$` and the symbol-narrow `$`. If the
     * locale has no narrow symbol, uses the standard symbol for the locale.
     *   - String: Use the given string value instead of a code or a symbol.
     * For example, an empty string will suppress the currency & symbol.
     *   - Boolean (marked deprecated in v5): `true` for symbol and false for `code`.
     *
     * @param digitsInfo Decimal representation options, specified by a string
     * in the following format:<br>
     * <code>{minIntegerDigits}.{minFractionDigits}-{maxFractionDigits}</code>.
     *   - `minIntegerDigits`: The minimum number of integer digits before the decimal point.
     * Default is `1`.
     *   - `minFractionDigits`: The minimum number of digits after the decimal point.
     * Default is `2`.
     *   - `maxFractionDigits`: The maximum number of digits after the decimal point.
     * Default is `2`.
     * If not provided, the number will be formatted with the proper amount of digits,
     * depending on what the [ISO 4217](https://en.wikipedia.org/wiki/ISO_4217) specifies.
     * For example, the Canadian dollar has 2 digits, whereas the Chilean peso has none.
     * @param locale A locale code for the locale format rules to use.
     * When not supplied, uses the value of `LOCALE_ID`, which is `en-US` by default.
     * See [Setting your app locale](guide/i18n-common-locale-id).
     */
    transform(value, currencyCode = this.__defaultCurrencyCode, display = 'symbol', digitsInfo, locale) {
        if (!isValue(value))
            return null;
        return super.transform(strToNumber(value) / 100, currencyCode, display, digitsInfo, locale);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCurrencyCentPipe, deps: [{ token: LOCALE_ID }, { token: DEFAULT_CURRENCY_CODE }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxCurrencyCentPipe, isStandalone: true, name: "currency" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxCurrencyCentPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'currency',
                    standalone: true,
                    pure: true,
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [LOCALE_ID]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [DEFAULT_CURRENCY_CODE]
                }] }] });
function isValue(value) {
    return !(value == null || value === '' || value !== value);
}
/**
 * Transforms a string into a number (if needed).
 */
function strToNumber(value) {
    // Convert strings to numbers
    if (typeof value === 'string' && !isNaN(Number(value) - parseFloat(value))) {
        return Number(value);
    }
    if (typeof value !== 'number') {
        throw new Error(`${value} is not a number`);
    }
    return value;
}

class DfxImplodePipe {
    transform(strings, separator, maxLength, suffix) {
        return s_imploder().source(strings).maxLength(maxLength).separator(separator).suffix(suffix).build();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodePipe, isStandalone: true, name: "s_implode" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_implode',
                    standalone: true,
                    pure: true,
                }]
        }] });
class ImplodeMappedPipe {
    transform(strings, mapFn, separator, maxLength, suffix) {
        return s_imploder().source(strings, mapFn).maxLength(maxLength).separator(separator).suffix(suffix).build();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ImplodeMappedPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: ImplodeMappedPipe, isStandalone: true, name: "s_implodeMapped" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: ImplodeMappedPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 's_implodeMapped',
                    standalone: true,
                    pure: true,
                }]
        }] });
const PIPES = [DfxImplodePipe, ImplodeMappedPipe];
class DfxImplodeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodeModule, imports: [DfxImplodePipe, ImplodeMappedPipe], exports: [DfxImplodePipe, ImplodeMappedPipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodeModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxImplodeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: PIPES,
                    exports: PIPES,
                }]
        }] });

class DfxArrayMapNamePipe {
    transform(it) {
        return it?.map((it) => it.name);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayMapNamePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayMapNamePipe, isStandalone: true, name: "a_mapName" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayMapNamePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'a_mapName',
                    standalone: true,
                    pure: true,
                }]
        }] });
class DfxMapNamePipe {
    transform(it) {
        return it?.name ?? '';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxMapNamePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxMapNamePipe, isStandalone: true, name: "o_mapName" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxMapNamePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'o_mapName',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxArrayPluck {
    transform(it, key) {
        return a_pluck(it, key);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayPluck, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayPluck, isStandalone: true, name: "a_pluck" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxArrayPluck, decorators: [{
            type: Pipe,
            args: [{
                    name: 'a_pluck',
                    standalone: true,
                    pure: true,
                }]
        }] });
class DfxPluck {
    transform(it, key) {
        return it[key];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxPluck, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxPluck, isStandalone: true, name: "o_pluck" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxPluck, decorators: [{
            type: Pipe,
            args: [{
                    name: 'o_pluck',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxTimeLeftPipe {
    transform(date, start) {
        return d_timeLeft(date, start);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeLeftPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeLeftPipe, isStandalone: true, name: "d_timeLeft" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeLeftPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'd_timeLeft',
                    standalone: true,
                    pure: true,
                }]
        }] });

class DfxTimeSpanPipe {
    transform(dateNow, dateFuture) {
        return d_timespan(dateNow, dateFuture);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeSpanPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeSpanPipe, isStandalone: true, name: "d_timespan" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxTimeSpanPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'd_timespan',
                    standalone: true,
                    pure: true,
                }]
        }] });

class IsMobileService {
    constructor() {
        this.#isMobileBreakpoint = inject(HELPER_MOBILE_BREAKPOINT);
        this.#viewportRuler = inject(ViewportRuler);
        this.#checkIsMobile = () => this.#viewportRuler.getViewportSize().width <= this.#isMobileBreakpoint;
        this.#_isMobile$ = this.#viewportRuler.change(50).pipe(map(this.#checkIsMobile), startWith(this.#checkIsMobile()), distinctUntilChanged());
        this.isMobile = toSignal(this.#_isMobile$, {
            initialValue: this.#checkIsMobile(),
        });
        this.isMobile$ = this.#_isMobile$.pipe(shareReplay(1));
    }
    #isMobileBreakpoint;
    #viewportRuler;
    #checkIsMobile;
    #_isMobile$;
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: IsMobileService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: IsMobileService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: IsMobileService, decorators: [{
            type: Injectable
        }] });
function injectIsMobile$() {
    return inject(IsMobileService).isMobile$;
}
function injectIsMobile() {
    return inject(IsMobileService).isMobile;
}
function provideIsMobileService() {
    return { provide: IsMobileService };
}

/* eslint-disable dot-notation */
class DfxPreloadStrategy {
    preload(route, loadMe) {
        if (route.data && route.data['preload']) {
            const delay = route.data['delay'] ?? 0;
            return timer(delay).pipe(mergeMap(() => loadMe()));
        }
        else {
            return of(null);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxPreloadStrategy, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxPreloadStrategy }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxPreloadStrategy, decorators: [{
            type: Injectable
        }] });

var HelperFeatureKind;
(function (HelperFeatureKind) {
    HelperFeatureKind[HelperFeatureKind["MOBILE_BREAKPOINT"] = 0] = "MOBILE_BREAKPOINT";
    HelperFeatureKind[HelperFeatureKind["BASE_URL_INTERCEPTOR"] = 1] = "BASE_URL_INTERCEPTOR";
    HelperFeatureKind[HelperFeatureKind["LOGGING_INTERCEPTOR_IGNORE_PATHS"] = 2] = "LOGGING_INTERCEPTOR_IGNORE_PATHS";
    HelperFeatureKind[HelperFeatureKind["POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS"] = 3] = "POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS";
    HelperFeatureKind[HelperFeatureKind["WINDOW"] = 4] = "WINDOW";
})(HelperFeatureKind || (HelperFeatureKind = {}));

function provideDfxHelper(...features) {
    console.log(getLogMessage('INFO', 'provideDfxHelper', 'setup', 'Features'), features);
    return makeEnvironmentProviders([features.map((it) => it.providers)]);
}
function withMobileBreakpoint(mobileBreakpoint) {
    return {
        kind: HelperFeatureKind.MOBILE_BREAKPOINT,
        providers: [{ provide: HELPER_MOBILE_BREAKPOINT, useValue: mobileBreakpoint }, provideIsMobileService()],
    };
}
function withBaseUrlInterceptor(baseUrl, paths = []) {
    return {
        kind: HelperFeatureKind.BASE_URL_INTERCEPTOR,
        providers: [
            { provide: HELPER_BASE_URL, useValue: baseUrl },
            { provide: HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS, useValue: paths },
        ],
    };
}
function withLoggingInterceptor(paths = []) {
    return {
        kind: HelperFeatureKind.LOGGING_INTERCEPTOR_IGNORE_PATHS,
        providers: [{ provide: HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS, useValue: paths }],
    };
}
function withPostPutJsonContentTypeInterceptor(paths = []) {
    return {
        kind: HelperFeatureKind.POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS,
        providers: [{ provide: HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS, useValue: paths }],
    };
}
function withWindow() {
    return {
        kind: HelperFeatureKind.WINDOW,
        providers: [provideWindow()],
    };
}

class DfxHelperModule {
    static setup(...features) {
        console.log(getLogMessage('INFO', 'provideDfxHelper', 'setup', 'Features'), features);
        return {
            ngModule: DfxHelperModule,
            providers: [features.map((it) => it.providers)],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHelperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.0", ngImport: i0, type: DfxHelperModule }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHelperModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.0", ngImport: i0, type: DfxHelperModule, decorators: [{
            type: NgModule
        }] });

/*
 * Public API Surface of dfx-helper
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AbstractIgnorableInterceptor, BASE_URL_INTERCEPTOR, BaseUrlInterceptor, ByPassInterceptorBuilder, DfxArrayMapNamePipe, DfxArrayPluck, DfxAutofocus, DfxBackDirective, DfxCountUp, DfxCurrencyCentPipe, DfxCutPipe, DfxHelperModule, DfxHideIfOffline, DfxHideIfOnline, DfxHideIfOnlineOfflineModule, DfxHideIfPingFails, DfxHideIfPingModule, DfxHideIfPingSucceeds, DfxImplodeModule, DfxImplodePipe, DfxIsEmailPipe, DfxIsUrlPipe, DfxLowerCaseExceptFirstLettersPipe, DfxMapNamePipe, DfxPluck, DfxPreloadStrategy, DfxStringModule, DfxStripWhitespacePipe, DfxTimeLeftPipe, DfxTimeSpanPipe, DfxTruncatePipe, DfxUpperCaseFirstLetterPipe, HELPER_BASE_URL, HELPER_BASE_URL_INTERCEPTOR_IGNORE_PATHS, HELPER_LOGGING_INTERCEPTOR_IGNORE_PATHS, HELPER_MOBILE_BREAKPOINT, HELPER_POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR_IGNORE_PATHS, HelperFeatureKind, ImplodeMappedPipe, IsMobileService, LOGGING_INTERCEPTOR, LoggingInterceptor, NgSub, NgSubContext, NgSubs, NgSubsContext, POST_PUT_JSON_CONTENT_TYPE_INTERCEPTOR, PostPutJsonContentTypeInterceptor, StopPropagationDirective, WINDOW, baseUrlInterceptor, injectIsMobile, injectIsMobile$, injectWindow, interceptorByPass, loggingInterceptor, postPutJsonContentTypeInterceptor, provideDfxHelper, provideIsMobileService, provideWindow, shouldIntercept, withBaseUrlInterceptor, withLoggingInterceptor, withMobileBreakpoint, withPostPutJsonContentTypeInterceptor, withWindow };
//# sourceMappingURL=dfx-helper.mjs.map
